.. _index:

===================================
UTA -- Universal Transcript Archive
===================================

.. include:: description.rst

Contents
--------

.. toctree::
   :maxdepth: 2

   overview
   examples
   
   getting_started
   installation
   
   database
   modules



Additional Resources
--------------------

* `UTA Code Repository and Issue Tracker`_

.. _UTA Code Repository and Issue Tracker: https://bitbucket.org/invitae/uta


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

